package com.ynet.life.cache;

import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_cache.jar:com/ynet/life/cache/LRUCache.class */
public class LRUCache implements Cache {
    private int cacheSize;
    private Map map = Collections.synchronizedMap(new HashMap());
    private List keyList = Collections.synchronizedList(new LinkedList());

    @Override // com.ynet.life.cache.Cache
    public Object get(Object key) {
        Object o = this.map.get(key);
        if (o != null) {
            this.keyList.remove(key);
            this.keyList.add(key);
        }
        return o;
    }

    @Override // com.ynet.life.cache.Cache
    public void put(Object key, Object value) {
        if (this.keyList.contains(key)) {
            return;
        }
        this.keyList.add(key);
        this.map.put(key, value);
        if (this.keyList.size() > this.cacheSize) {
            Object o = this.keyList.remove(0);
            this.map.remove(o);
        }
    }

    @Override // com.ynet.life.cache.Cache
    public void remove(Object key) {
        this.map.remove(key);
        this.keyList.remove(key);
    }

    @Override // com.ynet.life.cache.Cache
    public void clear() {
        this.map.clear();
        this.keyList.clear();
    }

    @Override // com.ynet.life.cache.Cache
    public void configure(int size) {
        this.cacheSize = size;
    }

    public static void main(String[] args) {
        LRUCache c = new LRUCache();
        c.configure(4);
        c.put("1", "1");
        c.put("2", "2");
        c.put("3", "3");
        c.put("4", "4");
        c.get("1");
        c.get("2");
        c.put("5", "5");
        c.put("5", "5");
        c.get("4");
        c.put("6", "6");
        System.out.println(c.get("4"));
    }

    @Override // com.ynet.life.cache.Cache
    public String getCacheName() {
        return null;
    }
}
